@@ -1,6 +1,6 @@
 """ Collection of commonly used constants for Luigi's Mansion. """
 
-CLIENT_VERSION = "V0.5.7"
+CLIENT_VERSION = "V0.5.8"
 CLIENT_NAME = "Luigi's Mansion Client"
 
 AP_LOGGER_NAME = "Client"
@@ -26,3 +26,14 @@ ROOM_ID_OFFSET = 0x35C
 WAIT_TIMER_SHORT_TIMEOUT: float = 0.125
 WAIT_TIMER_MEDIUM_TIMEOUT: float = 1.5
 WAIT_TIMER_LONG_TIMEOUT: float = 5
+
+class MEMORY_CONSTANTS:
+    """ Constants which reference Luigi's Mansion memory allocations. """
+
+    TRAINING_BUTTON_LAYOUT_SCREEN = 0x803D33AE
+    """ Flag 168: Room flag used to determine if the button layout screen during training is present. """
+
+    class TRAP_CONSTANTS:
+        """ Memory Allocations for Archipelago TrapLink. """
+        VAC_TRAP_IS_ACTIVE = 0x804ddf1c
+        """ Determines if the vac_trap is active. The value is -1 on inactivity. """
